@@ -7,6 +7,14 @@ GB_MESSAGES['InformationUpdateError'] = '情報の更新でエラーが発生し
 GB_MESSAGES['NoCrdID'] = '指定されたIDの座標系(crd)が見つかりませんでした。';
 GB_MESSAGES['ThereisNoObject'] = '指定されたオブジェクトがありませんでした。';
 
+var RDF_NS = ["rdf", "http://www.w3.org/1999/02/22-rdf-syntax-ns#"];
+var GB_NS = ["gb", "http://www.globalbase.org/spec/http-rss/0.1/"];
+
+function gbGetHttpStatusCode(req){
+	var statusLine = req.getResponseHeader("X-GB-Server-Status-Line");
+	return parseInt(statusLine.substr(statusLine.indexOf(" ")));
+}
+
 function gbPoint(x,y)
 {
 	if(x == undefined){
@@ -111,8 +119,8 @@ gbTarget.prototype.initByXML = function(x){
 
 gbTarget.prototype.updateByParamStr = function(paramStr)
 {
+	paramStr = decodeURIComponent(paramStr);
 	var params = paramStr.split("_");
-//	this.coord = unescape(params[0]);
 	this.coord = params[0];
 	this.position = new gbPosition(
 			params[1],
@@ -126,7 +134,6 @@ gbTarget.prototype.updateByParamStr = function(paramStr)
 
 gbTarget.prototype.toQuery = function()
 {
-//	return "" + escape(this.coord) + "_" + this.position.toQuery();
 	return "" + this.coord + "_" + this.position.toQuery();
 }
 
@@ -168,7 +175,7 @@ gbCoord.prototype.initByXML = function(coordXML)
 
 gbCoord.prototype.toQuery = function()
 {
-	return escape(this.id + "(" + (this.locked?"L":"") + (this.visible?"1":"0") + ")");
+	return encodeURIComponent(this.id + "(" + (this.locked?"L":"") + (this.visible?"1":"0") + ")");
 }
 
 gbCoord.prototype.getHTML = function()
@@ -257,7 +264,7 @@ gbLayer.prototype.initByXML = function(layerXML)
 
 gbLayer.prototype.toQuery = function()
 {
-	return escape(this.id) + (this.visible?"[1]":"[0]");
+	return encodeURIComponent(this.id) + (this.visible?"[1]":"[0]");
 }
 
 
@@ -283,15 +290,15 @@ gbLayer.prototype.getItemById = function(id){
 }
 
 gbLayer.prototype.updateByParams = function(params){
-	var v=false;
 	var i=0;
+	var v=false;
 	for(; i<params.length; ++i){
 		if(params[i][0] == this.id){
-			v = params[i][1]=="1";
+			v = (params[i][1]=="1");
+			this.setVisible(v);
 			break;
 		}
 	}
-	this.setVisible(v);
 	return v;
 }
 
@@ -397,10 +404,11 @@ gbLayerGroup.prototype.updateByParams = function(params){
 	for(var i=0; i<params.length; ++i){
 		if(params[i][0] == this.id){
 			v = params[i][1]=="1";
+			this.setVisible(v);
 			break;
 		}
 	}
-	this.setVisible(v);
+	
 	for(var i=0; i<this.layers.length; ++i){
 		if(this.layers[i].updateByParams(params)){
 			this.expand = true;
@@ -572,7 +580,7 @@ gbLayerCtrl.prototype.updateDepth = function(){
 }
 
 gbLayerCtrl.prototype.updateByParamStr = function(paramStr){
-	var paramStr = unescape(paramStr);
+	// var paramStr = decodeURIComponent(paramStr);
 	// trace("gbLayerCtrl.prototype.updateByParamStr called paramStr="+paramStr);
 	
 	var params = paramStr.split("]");
@@ -590,7 +598,7 @@ function gbImageStatus(app){
 	this.taskCount = 0;
 	this.isDirty = true;
 	this.crdStatus = "";
-	this.resourcePath = "";
+//	this.resourcePath = "";
 	this.resetInterval();
 	this.app = app;
 	this.timeoutId = -1;
@@ -625,7 +633,7 @@ gbImageStatus.prototype.resetInterval = function()
 	this.nextInterval = 100;
 }
 
-gbImageStatus.prototype.setNextStatus = function(resourcePath, taskCount, isDirty, crdStatus)
+gbImageStatus.prototype.setNextStatus = function(/*resourcePath,*/ taskCount, isDirty, crdStatus)
 {
 	this.cancelNextTimeout();
 	if(!this.isDirty && !isDirty && (taskCount==0)){
@@ -646,7 +654,7 @@ gbImageStatus.prototype.setNextStatus = function(resourcePath, taskCount, isDirt
 		}
 	}
 	
-	this.resourcePath = resourcePath;
+//	this.resourcePath = resourcePath;
 	this.taskCount = taskCount;
 	this.isDirty = isDirty;
 	this.crdStatus = crdStatus;
@@ -775,13 +783,14 @@ gbMark.prototype.getImgURL = function(){
         return "";
     }
     
-	if( (img.indexOf('http://') != 0) && (img.indexOf('https://') != 0) ){
+	if(img.match(/^((xlp)|(https?))\:\/\//)){
+	    return ret;
+	}
+	else{
 		var path = getCurrentPath();
 		path = path.substring(0,path.length-1);
 	    return path.substring(0, path.lastIndexOf('/')+1) + img;
 	}
-	
-    return ret;
 }
 
 gbMark.prototype.getTransparentColor = function(){
@@ -814,7 +823,7 @@ gbEditableVct.prototype.initByXML = function(node){
     }
     
     if(this.plotableMarks.length == 0){
-        alert("[xml error] no plotable mark found in editableVct element. editableVct="+node);
+        alert("[xml error] no plotable mark found in editableVct element. check client_conf.xml");
     }    
     
 	// this.markImageURL = node.getAttribute("defaultMarkImage");
@@ -875,6 +884,8 @@ function gbApp(){
 	this.id = gbApp.instances.length-1;
 	this.modalDialog = null;
 	
+	this.projectionType = gbApp.PT_LINEAR;
+	
 	// for edit mode 
 	this.sessionId = null;
 	this.editableVctAry = [];
@@ -952,11 +963,17 @@ gbApp.prototype.moveImageTo = function(xoffset, yoffset, hilight_key)
 	
 	// trace("gbApp.prototype.moveImageTo this.imageObj="+this.imageObj);
 	
-	var anim = this.getNewAnim();
-	anim.init(this.imageObj, xdest, ydest, 1, 2*Math.sqrt(xoffset*xoffset+yoffset*yoffset), {obj:this, method:"onFinishImageAnim", args:""});
-	anim.hilightKey = hilight_key;
+	var finishAnimHandler = {obj:this, method:"onFinishImageAnim", args:""};
 	
-	this.kickImageAnim();
+	if(this.projectionType == gbApp.PT_LINEAR){
+		var anim = this.getNewAnim();
+		anim.init(this.imageObj, xdest, ydest, 1, 2*Math.sqrt(xoffset*xoffset+yoffset*yoffset), finishAnimHandler);
+		anim.hilightKey = hilight_key;
+		this.kickImageAnim();
+	}
+	else{
+		finishAnimHandler.obj[finishAnimHandler.method](finishAnimHandler.args);
+	}
 	
 	return true;
 }
@@ -1001,6 +1018,31 @@ gbApp.prototype.applyImageSizeToHtml = function(){
 	this.imageObj.style.height = this.imageHeight;
 }
 
+gbApp.prototype.initImageByXMLNode = function(node){
+trace("gbApp.prototype.initByXML image 2");
+	var htmlId = node.getAttribute("htmlId");
+trace("gbApp.prototype.initByXML image 3");
+	if(htmlId != null){
+trace("gbApp.prototype.initByXML image 4");
+		this.imageName = htmlId;
+trace("gbApp.prototype.initByXML image 5");
+	}
+trace("gbApp.prototype.initByXML image 6");
+	this.imageWidth = parseInt(node.getAttribute("width"));
+trace("gbApp.prototype.initByXML image 7");
+	this.imageHeight = parseInt(node.getAttribute("height"));
+trace("gbApp.prototype.initByXML this.imageName="+this.imageName);
+	this.imageObj = getObjectById(this.imageName);
+trace("gbApp.prototype.initByXML this.imageObj="+this.imageObj);
+	
+	this.applyImageSizeToHtml();
+	
+	var t = node.getAttribute("infoTargetWindow");
+	if(t){
+		this.infoTargetWindow = t;
+	}
+}
+
 gbApp.prototype.initByXML = function(x)
 {
 	this.confXML = x;
@@ -1015,24 +1057,10 @@ gbApp.prototype.initByXML = function(x)
 	for(var i=0; i<elements.length; ++i){
 		switch(elements[i].nodeName){
 			case "image":
-				{
-					var img = elements[i];
-					var htmlId = img.getAttribute("htmlId");
-					if(htmlId != null){
-						this.imageName = htmlId;
-					}
-					this.imageWidth = parseInt(img.getAttribute("width"));
-					this.imageHeight = parseInt(img.getAttribute("height"));
-					this.imageObj = getObjectById(this.imageName);
-					this.applyImageSizeToHtml();
-					
-					var t = img.getAttribute("infoTargetWindow");
-					if(t){
-						this.infoTargetWindow = t;
-					}
-				}
+			case "img": // safari
+				this.initImageByXMLNode(elements[i]);
 				break;
-				
+			
 			case "layerCtrl":
 				this.layerCtrl = new gbLayerCtrl(this);
 				this.layerCtrl.initByXML(elements[i]);
@@ -1062,7 +1090,6 @@ gbApp.prototype.initByXML = function(x)
 		}
 	}
 	
-	
 }
 
 
@@ -1195,8 +1222,7 @@ gbApp.prototype.clearOldImage = function()
 
 gbApp.prototype.applyLoadedImage = function()
 {
-	
-	// trace("applyLoadedImage called this.newImageObj="+this.newImageObj);
+// trace("applyLoadedImage called this.newImageObj="+this.newImageObj);
 	this.imageLoader.img = null;
 	this.clearOldImage();
 	this.oldImageObj = this.imageObj;
@@ -1552,7 +1578,9 @@ gbApp.prototype.onMouseDownImage = function()
 				
 				if(area && area.isEditable(this.activeVct.id)){
 			        if(this.mode == 'delete'){
-						area.makeSureDetailLoaded();
+						if(!area.makeSureDetailLoaded()){
+							return;
+						}
 			            if(confirm("プロット"+area.getDisplayName()+"を削除してもよろしいですか？")){
 			                this.doEditCommand({md:'delete', objCode:area.objCode});
 			                return;
@@ -1586,7 +1614,7 @@ gbApp.prototype.infoRequest = function()
 	var query = this.getQuery('info2');
 	// trace("info request quelr="+query);
 	
-	var req = doRequest(this.cgiPath+"?"+query, false);
+	var req = doRequest(this.getCgiPath()+"?"+query, false);
 	if(isResponseOK(req)){
 		showPopup(req.responseText, this.popupObj);
 	}
@@ -1629,8 +1657,8 @@ gbApp.prototype.onUnload = function(){
 
 gbApp.prototype.setCookie = function()
 {
-	document.cookie = "lastAccessParam="+escape(this.getCurrentParams())+";";
-	document.cookie = "cookiedURL="+escape(document.location)+";";
+	document.cookie = "lastAccessParam="+encodeURIComponent(this.getCurrentParams())+";";
+	document.cookie = "cookiedURL="+encodeURIComponent(document.location)+";";
 }
 
 gbApp.prototype.initByCookie = function()
@@ -1642,13 +1670,14 @@ gbApp.prototype.initByCookie = function()
 		var vars = document.cookie.split(/; ?/);
 		for(var i=0; i<vars.length; ++i){
 			var value = vars[i].split("=");
+			value[1] = decodeURIComponent(value[1]);
 			if(value.length==2){
 				switch(value[0]){
 					case "lastAccessParam":
-						lastAccessParam = unescape(value[1]);
+						lastAccessParam = value[1];
 					break;
 					case "cookiedURL":
-						cookiedURL = unescape(value[1]);
+						cookiedURL = value[1];
 					break;
 				}
 			}
@@ -1662,6 +1691,27 @@ gbApp.prototype.initByCookie = function()
 	}
 }
 
+gbApp.prototype.execTrackBack = function()
+{
+	trace("gbApp.prototype.execTrackBack");
+	var ua = navigator.userAgent.toUpperCase();
+	trace("gbApp.prototype.execTrackBack ua="+ua);
+//	if(ua.match(/MSIE/) && ua.match(/WINDOWS/)){
+//	if(!ua.match(/SAFARI/)){
+		document.location = this.cgiPath.replace("gbgate\.cgi", "trackback.cgi") + "?param="+encodeURIComponent(this.getCurrentParams());
+//	}
+}
+
+gbApp.prototype.getTrackBackText = function()
+{
+	trace("gbApp.prototype.getTrackBackText");
+	var path = this.cgiPath.replace("gbgate\.cgi", "getgburl.cgi");
+	trace("gbApp.prototype.getTrackBackText path="+path);
+	var ret = '<trackback>' + doGetText(path) + '?' + this.getCurrentParams() + '</trackback>';
+	trace("gbApp.prototype.getTrackBackText ret="+ret);
+	return ret;
+}
+
 gbApp.prototype.updateImage = function(isAbortCurrent){
 	// trace("gbApp.prototype.updateImage called isAbortCurrent="+isAbortCurrent);
 	var oldImageStatus=null;
@@ -1786,6 +1836,7 @@ gbApp.prototype.initByAccessParam = function(paramStr){
 	var params = paramStr.split('&');
 	for(var i=0;i<params.length; ++i){
 		params[i] = params[i].split('=');
+		params[i][1] = decodeURIComponent(params[i][1]);
 		switch(params[i][0]){
 			case "l":
 				this.layerCtrl.updateByParamStr(params[i][1]);
@@ -1821,31 +1872,12 @@ gbApp.prototype.setEdit = function(){
 	if(result != null){
 		this.isEdit = true;
 		
-		var sessionElements = result.getElementsByTagName('session');
-		if(sessionElements!=null && sessionElements.length>0){
-			this.sessionId = sessionElements[0].getAttribute('id');
-			if(this.sessionId == null || this.sessionId == undefined){
-				// trace("session-id missing in session node.");
-			}
+		var sessionNode = xmlFindChildElement(result, 'session');
+		if(sessionNode){
+			alert(" debug ");
+			this.sessionId = sessionNode.getAttribute('id');
+			alert(" debug this.sessionId="+this.sessionId);
 		}
-		else{
-			// trace("session-id missing in the open command response. session node needed.");
-		}
-		// <iframe name="fileupResultIframe" id="fileupResultIframe" style="width:0px; height:0px; border-width:0px"></iframe>
-		/*
-		var obj = getObjectById("fileupResultIframe");
-		if(obj==null || obj==undefined){
-			
-			var ifr = document.createElement("iframe");
-			ifr.setAttribute("name","fileupResultIframe");
-			ifr.setAttribute("id","fileupResultIframe");
-			ifr.style.width = "100px";
-			ifr.style.height = "100px";
-			ifr.style.borderWidth = "0px";
-			document.body.appendChild(ifr);
-			
-		}
-		*/
 	}
 	
 }
@@ -1858,15 +1890,61 @@ gbApp.prototype.doEditCommand = function(params){
 	if(this.activeVct){
 		params.vct = this.activeVct.getId();
 	}
-	var ret = this.doCommand(params,"POST");
-	this.updateImage();
-	return ret;
+	var ret = this.doCommand(params, "POST", false);
+	if(ret){
+		this.updateImage();
+		return ret.documentElement;
+	}
+	else{
+		return null;
+	}
 }
 
-gbApp.prototype.doCommand = function(params, method){
+function gbCheckHttpResponse(req)
+{
+	var code = gbGetHttpStatusCode(req);
+	if(code != 200){
+		throw ("GLOBALBASE server error. http status code="+code+"\n---response---\n"+req.responseText);
+	}
+}
+
+gbApp.prototype.checkCommandResponse = function(req)
+{
+	// trace("doCommand server response="+req.responseText);
 	
+	if(!isResponseOK(req)){
+		throw "doCommand request error.";
+	}
+	
+	gbCheckHttpResponse(req);
+	
+	var x = req.responseXML;
+	if(x.documentElement==null){
+		throw  "server error response \n"+req.responseText;
+	}
+	if(x.documentElement.nodeName != "gvha-status"){
+		throw "root node was not \"gvha-status\". \n"+req.responseText;
+	}
+	
+	var resultNode = xmlFindChildElement(x.documentElement, 'result');
+	if(!resultNode){
+		throw "command result not found";
+	}
+	
+	var type = resultNode.getAttribute('type');
+	if(type != 'ok'){
+		if(GB_MESSAGES[type]==undefined){
+			throw "undefined result type. type="+type+" errorMessage="+getChildrenText(resultNode);
+		}
+		else{
+			throw GB_MESSAGES[type]+"("+type+")"+getChildrenText(resultNode);
+		}
+	}
+}
+
+gbApp.prototype.doCommand = function(params, method, async){
 	var req = getRequest();
-	req.open(method, this.cgiPath, false/*async*/);
+	req.open(method, this.getCgiPath(), async);
 	req.setRequestHeader("Content-Type","application/x-www-form-urlencoded");
 	
 	var paramStr='';
@@ -1874,66 +1952,23 @@ gbApp.prototype.doCommand = function(params, method){
 		if(paramStr!=''){
 			paramStr+='&';
 		}
-		paramStr+=param + '=' + escape(params[param]);
+		paramStr+=param + '=' + encodeURIComponent(params[param]);
 	}
 	
-	// trace("doEditCommand paramStr="+paramStr);
+	// trace("doCommand paramStr="+paramStr);
 	req.send(paramStr);
 	
-	var isOk = false;
-	
-	// trace("doEditCommand server response="+req.responseText);
-	var errorMessage=null;
-	if(isResponseOK(req)){
-		var x = req.responseXML;
-		if(x.documentElement==null){
-			alert("server error response \n"+req.responseText);
+	if(!async){
+		try{
+			this.checkCommandResponse(req);
+		}
+		catch(e){
+			trace(e);
+			alert(e);
 			return null;
 		}
-		if(x.documentElement.nodeName != "gvha-status"){
-			alert("root node was not \"gvha-status\". \n"+req.responseText);
-			return null;
-		}
-		
-		var node = x.documentElement.firstChild;
-		for(; node!=null; node=node.nextSibling){
-			switch(node.nodeName){
-				case 'result':
-				{
-					var type = node.getAttribute('type');
-					if(type == 'ok'){
-						isOk = true;
-					}
-					else{
-						if(GB_MESSAGES[type]==undefined){
-							errorMessage = "undefined result type. type="+type+" errorMessage="+getChildrenText(node);
-						}
-						else{
-							errorMessage = GB_MESSAGES[type]+"("+type+")"+getChildrenText(node);
-						}
-					}
-				}
-				break;
-			}
-			if(isOk){
-				break;
-			}
-		}
-		if(isOk){
-			return x.documentElement;
-		}
 	}
-	else{
-		errorMessage = "editCommand request error.";
-	}
-	
-	if(errorMessage){
-	    // trace("");
-	    // trace("errorMessage=" + errorMessage);
-	    alert(errorMessage);
-	}
-	
-	return null;
+	return req;
 }
 
 
@@ -1960,6 +1995,10 @@ gbApp.prototype.editForm_close = function(btn){
 	this.modalDialog.close(btn);
 }
 
+// ProjectionTypes (for gb:status-projection-type)
+gbApp.PT_LINEAR = 1;
+gbApp.PT_SPHERE = 2;
+
 function gbImageLoader(app, query, imageStatus){
 	this.app = app;
 	this.query = query;
@@ -1976,7 +2015,6 @@ function gbImageLoader(app, query, imageStatus){
 	this.reqObj = null;
 	this.imageQueryStr = null;
 	this.queryParams = null;
-	
 	this.clickableMaps = null;
 }
 gbImageLoader.prototype = new gbObj();
@@ -2006,7 +2044,6 @@ gbImageLoader.prototype.start = function()
 {
 	this.setStatus(gbImageLoader.LOADING_RSS);
 // trace("get rss request query="+this.query);
-	
 	this.reqObj = doAsyncRequest(this.getApp().getCgiPath()+"?"+this.query, {obj:this, method:"onLoadRSS", args:""});
 }
 
@@ -2020,6 +2057,7 @@ gbImageLoader.prototype.onStatusMsg = function(msg){
 	
 }
 
+
 gbImageLoader.prototype.onLoadRSS = function(is_success, req, userArg)
 {
 	if(!is_success){
@@ -2028,13 +2066,20 @@ gbImageLoader.prototype.onLoadRSS = function(is_success, req, userArg)
 		return;
 	}
 	if(req.readyState != 4){
-		// trace("onLoadRSS called by aborted request");
 		// aborted response
 		return;
 	}
+	try{
+		gbCheckHttpResponse(req);
+	}
+	catch(e){
+		trace(e);
+		alert(e);
+		return;
+	}
 	
 	// trace("gbImageLoader.onLoadRSS responseText.length="+req.responseText.length);
-	trace("RESPONSE RSS FILE ="+req.responseText);
+	// trace("RESPONSE RSS FILE ="+req.responseText);
 	
 	var x = req.responseXML;
 	if(x.parsed!=undefined && x.parsed==false){
@@ -2044,54 +2089,57 @@ gbImageLoader.prototype.onLoadRSS = function(is_success, req, userArg)
 		timeoutid = window.setTimeout(function(){loader.onLoadRSS(is_success, req, userArg); window.clearTimeout(timeoutid);}, 0);
 		return;
 	}
-	
+
 	this.setStatus(gbImageLoader.LOADED_RSS);
-	
-	var images = getElementsByTagName_alt(x, "rdf:li", "li");
+	var images = getElementsByTagName_alt(x, RDF_NS, "li");
 	// trace("images.length="+images.length);
 	if(images.length == 0){
 		alert("rdf:li not found in server response rss.");
 		return;
 	}
 	
-	var resource = images[0].getAttribute("rdf:resource");
+	var resource = xmlGetAttributeNS(images[0], RDF_NS, "resource");
+	
+	var projectionType = getElementsByTagName_alt(x, GB_NS, "status-projection-type");
+	if(projectionType && projectionType.length>0){
+		this.app.projectionType = Number(getChildrenText(projectionType[0]));
+	}
 	
 	// trace("resource="+resource);
-	var items = x.getElementsByTagName("item");
-	
+	var items = getElementsByTagName_alt(x, null, "item");
 	for(var i=0; i<items.length; ++i){
-		var rdfAbout = items[i].getAttribute("rdf:about");
+		var rdfAbout = xmlGetAttributeNS(items[i], RDF_NS, "about");
+		
 		if(rdfAbout == resource){
-			
-//			var link = items[i].getElementsByTagName("link");
-//			resource = getChildrenText(link[0]);
-			
-			var stat1 = getElementsByTagName_alt(items[i], "gb:status1", "status1");
+			var stat1 = getElementsByTagName_alt(items[i], GB_NS, "status1");
 			
 			var taskCount = Number(getChildrenText(stat1[0]));
 			
-			var stat2 = getElementsByTagName_alt(items[i], "gb:status2", "status2");
+			var stat2 = getElementsByTagName_alt(items[i], GB_NS, "status2");
 			var isDirty = (Number(getChildrenText(stat2[0])) == 1);
 			
-			var stat3 = getElementsByTagName_alt(items[i], "gb:status3", "status3");
+			var stat3 = getElementsByTagName_alt(items[i], GB_NS, "status3");
 			var crdStatus="";
 			if(stat3.length!=0){
 				crdStatus = getChildrenText(stat3[0]);
 			}
 			
-			var map_xml = getElementsByTagName_alt(items[i], "gb:html-map", "html-map");
+			var map_xml = getElementsByTagName_alt(items[i], GB_NS, "html-map");
 			if(map_xml.length!=0){
 				this.clickableMaps = new gbClickableMaps(this.app);
 				this.clickableMaps.initByXML(map_xml[0]);
 			}
 			
 			// trace("taskCount="+taskCount+ " crdStatus="+crdStatus+ " isDirty="+isDirty);
-			this.imageStatus.setNextStatus(resource, taskCount, isDirty, crdStatus);
+			this.imageStatus.setNextStatus(taskCount, isDirty, crdStatus);
 			
 			break;
 		}
 	}
 	
+	// for safari bug?
+	resource = resource.replace(/\&\#38\;/g, "&");
+	
 	var pos = resource.indexOf("?");
 	this.imageQueryStr="";
 	if(pos != -1){
@@ -2099,9 +2147,11 @@ gbImageLoader.prototype.onLoadRSS = function(is_success, req, userArg)
 	}
 	
 	var params = this.imageQueryStr.split("&");
+	
 	for(var i=0; i<params.length; ++i){
 		params[i] = params[i].split("=");
 		var param = params[i];
+//		param[1] = decodeURIComponent(param[1]);
 		switch(param[0]){
 			case 't':
 				this.target = new gbTarget();
@@ -2114,8 +2164,10 @@ gbImageLoader.prototype.onLoadRSS = function(is_success, req, userArg)
 				break;
 		}
 	}
+	
 	this.queryParams = params;
 	
+	
 	var is_complete_forced=false;
 	
 	// don't use cache while edit mode
@@ -2130,6 +2182,7 @@ gbImageLoader.prototype.onLoadRSS = function(is_success, req, userArg)
 		}
 	}
 	
+	
 	if(!is_complete_forced){
 		// for no cache
 		if(pos==-1){
@@ -2138,35 +2191,22 @@ gbImageLoader.prototype.onLoadRSS = function(is_success, req, userArg)
 			resource += "&n="+(new Date()).getTime();
 		}
 	}
-	
-	
-	this.img = document.createElement("img");
-	this.img.src = resource;
-	this.img.style.width = this.iamgeWidth;
-	this.img.style.height = this.iamgeHeight;
-	
-	this.onBeginLoadImage(this.img);
-	
-	// trace("gbImageLoader this.img.complete="+this.img.complete);
+
+//	this.onBeginLoadImage(this.img);
+	this.img = this.createNewImage();
 	
 	var loader = this;
-	if(this.img.complete){
-		// trace("**** resouce:"+resource+" was cached. ****");
-		this.setStatus(gbImageLoader.LOADED_IMAGE);
-		this.onCompleteLoadImage(this.img);
-	}
-	else{
-		// trace("**** resouce:"+resource+" was NOT cached. ****");
-		this.setStatus(gbImageLoader.LOADING_IMAGE);
-		
-		this.img.onload = function(){
-			if(loader.img!=null){
-				loader.setStatus(gbImageLoader.LOADED_IMAGE);
-				loader.onCompleteLoadImage(this);
-				this.onload=null;
-			}
+	attachImgEvent(this.img, function(){
+		if(loader.img!=null){
+			loader.setStatus(gbImageLoader.LOADED_IMAGE);
+			loader.onCompleteLoadImage(this);
+			this.onload=null;
 		}
-	}
+	},function(){alert("error loading image");});
+	// trace("resource=    "+resource);
+	this.img.src = resource;
+	this.setStatus(gbImageLoader.LOADING_IMAGE);
+	
 }
 
 /*private*/
@@ -2210,12 +2250,17 @@ gbImageLoader.prototype.onStatusMsg = function(msg){
 	this.app.setStatusMsg(msg);
 }
 
-gbImageLoader.prototype.onBeginLoadImage = function(img){
+gbImageLoader.prototype.createNewImage = function(){
+	
+	var img = document.createElement("img");
+	img.style.width = this.iamgeWidth;
+	img.style.height = this.iamgeHeight;
 	img.className = "image_style";
 	this.app.imageObj.style.zIndex = 1;
 	img.style.zIndex = 2;
 	img.style.left = -this.app.imageWidth;
 	this.app.getImageWrap().appendChild(img);
+	return img;
 }
 
 gbImageLoader.prototype.onCompleteLoadImage = function(img){
@@ -2267,18 +2312,17 @@ gbClickableArea.prototype.setupInfoAndHtmlDataByXMLNode = function(node){
 
 gbClickableArea.prototype.makeSureDetailLoaded = function(){
 	if(!this.infoXML){
-		// var wait = getObjectById('waitDialog');
-		// wait.style.visibility = 'visible';
-		var result = this.app.doCommand({md:'object', objCode:this.objCode, vct:this.resourceId}, 'POST');
-		// wait.style.visibility = 'hidden';
+		var result = this.app.doCommand({md:'object', objCode:this.objCode, vct:this.resourceId}, 'POST', false);
+		if(result == null){
+			return false;
+		}
 		
-		if(result != null){
-			var objNodes = result.getElementsByTagName('gvha-object');
-			if(objNodes!=null && objNodes.length>0){
-				this.setupInfoAndHtmlDataByXMLNode(objNodes[0]);
-			}
+		var objNodes = getElementsByTagName_alt(result.responseXML, null, 'gvha-object');
+		if(objNodes!=null && objNodes.length>0){
+			this.setupInfoAndHtmlDataByXMLNode(objNodes[0]);
 		}
 	}
+	return true;
 }
 
 
@@ -2297,12 +2341,12 @@ gbClickableArea.prototype.isEditable = function(resourceId){
 
 gbClickableArea.prototype.getDisplayName = function(){
     if(this.infoXML){
-        var nameNodes = getElementsByTagName_alt(this.infoXML, "name", "name");
-		if(nameNodes.length!=0){
+        var nameNodes = getElementsByTagName_alt(this.infoXML, null, "name");
+        if(nameNodes.length!=0){
 		    return getChildrenText(nameNodes[0]);
 		}
 		
-		var fieldNodes = getElementsByTagName_alt(this.infoXML, 'gb:field', 'field');
+		var fieldNodes = getElementsByTagName_alt(this.infoXML, GB_NS, 'field');
 		if(fieldNodes.length!=0){
 		    for(var i=0; i<fieldNodes.length; ++i){
 			    if(fieldNodes[i].getAttribute('name') == 'name'){
@@ -2349,6 +2393,11 @@ gbClickableArea.prototype.showInfo = function()
 		}else{
 			form.innerHTML = infoTableHead + infoTableBody + infoTableFoot;
 			form.style.visibility = 'visible';
+			
+			var anchors = getElementsByTagName_alt(form, null, 'a');
+			for(var i=0; i<anchors.length; ++i){
+				anchors[i].target = this.app.infoTargetWindow;
+			}
 		}
 	}
 	else{
@@ -2434,52 +2483,15 @@ function gbEditFormPlot(app, type, param){
         this.area = area;
         this.area.makeSureDetailLoaded();
         if(area.infoXML == null){
-			/*
-			this.addItem(true,"name", "");
-			this.addItem(true,"url", "");
-			this.scheme = app.activeVct.defaultScheme;
-			*/
-			
 			this.setupItemsByInfoXML(app.activeVct.defaultInfo);
 		}
 		else{
 			this.setupItemsByInfoXML(area.infoXML);
-			/*
-			this.scheme = area.infoXML.getAttribute("scheme");
-            for(var node = area.infoXML.firstChild;
-                node!=null; node=node.nextSibling){
-                if(node.nodeType == 1){
-                    for(var child = node.firstChild;
-                        child != null;
-                        child = child.nextSibling){
-                        if(child.nodeType == 1){
-                            throw ("このプロットには、対応していない形式のinformationが設定されています。 information="+getChildrenText(area.infoXML));
-                        }
-                    }
-                    
-                    var fieldName;
-                    if(node.nodeName == "field"){
-						fieldName = node.getAttribute('name');
-					}
-					else{
-						fieldName = node.nodeName;
-					}
-                    
-                    this.addItem(
-                    	true,
-                    	fieldName,
-                    	getChildrenText(node),
-                    	node.getAttribute('visible'),
-                    	node.getAttribute('href'),
-                    	node.getAttribute('media'));
-                }
-            }
-            */
         }
         emoveButton.style.visibility = 'inherit';
     }
     else{
-        throw "対応していないタイプです。 type="+type;
+        throw "invalid dialog type type="+type;
     }
 	
 }
@@ -2490,9 +2502,12 @@ gbEditFormPlot.prototype = new gbObj();
 gbEditFormPlot.prototype.setupItemsByInfoXML = function(infoXML)
 {
 	this.scheme = infoXML.getAttribute("scheme");
-    for(var node = infoXML.firstChild;
+	this.setAnchorByXML(null);
+
+	for(var node = infoXML.firstChild;
         node!=null; node=node.nextSibling){
-        if(node.nodeType == 1){
+		
+		if(node.nodeType == 1){
             for(var child = node.firstChild;
                 child != null;
                 child = child.nextSibling){
@@ -2505,10 +2520,13 @@ gbEditFormPlot.prototype.setupItemsByInfoXML = function(infoXML)
             if(node.nodeName == "field"){
 				fieldName = node.getAttribute('name');
 			}
+			else if( (node.nodeName == "anchor") || (node.nodeName == "a") ){
+				this.setAnchorByXML(node);
+				continue;
+			}
 			else{
 				fieldName = node.nodeName;
 			}
-            
             this.addItem(
             	true,
             	fieldName,
@@ -2520,6 +2538,22 @@ gbEditFormPlot.prototype.setupItemsByInfoXML = function(infoXML)
     }
 }
 
+gbEditFormPlot.prototype.setAnchorByXML = function(anchorNode){
+	var tbody = getObjectById("editFormTbody");
+	var inputs = getElementsByTagName_alt(tbody, null, "input");
+	for(var i=0; i< inputs.length; ++i){
+		if(inputs[i].name == "anchor"){
+			if(anchorNode){
+				inputs[i].value = getChildrenText(anchorNode);
+			}
+			else{
+				inputs[i].value = "";
+			}
+			break;
+		}
+	}
+}
+			
 
 gbEditFormPlot.prototype.show = function(){
 	var obj = getObjectById(this.htmlId);
@@ -2537,58 +2571,65 @@ gbEditFormPlot.prototype.getInfoXML = function()
 	
 	var fieldName;
     var tbody = getObjectById('editFormTbody');
-    var inputs = tbody.getElementsByTagName('input');
-	var selects = tbody.getElementsByTagName('select');
+    var inputs = getElementsByTagName_alt(tbody, null, 'input');
+	var selects = getElementsByTagName_alt(tbody, null, 'select');
 	
 	
 	for(var i=0; i<inputs.length; ++i){
+    	if(inputs[i].name == "anchor"){
+			if(inputs[i].value != ""){
+				information += "<anchor>"+escapeForXML(inputs[i].value)+"</anchor>";
+			}
+		}
+    }
+    
+    for(var i=0; i<inputs.length; ++i){
         var inp = inputs[i];
         var inputName = inp.name;
-        if(inputName){
-            if(inputName.indexOf('fieldName') == 0){
-				var itemID = inputName.substr('fieldName'.length, inputName.length);
-				var fieldValue;
-				var fieldName = inp.value;
-				var href = null;
-				
-				var visible = 'off';
-				var media = 'off';
-				
-				for(var j=0; j<inputs.length; ++j){
-					if(inputs[j].name == 'fieldValue' + itemID){
-						fieldValue = escapeForXML(inputs[j].value);
-					}
-					if(inputs[j].name == 'href' + itemID){
-						href = escapeForXML(inputs[j].value);
-					}
+        if(!inputName){
+			continue;
+		}
+		else if(inputName.indexOf('fieldName') == 0){
+			var itemID = inputName.substr('fieldName'.length, inputName.length);
+			var fieldValue;
+			var fieldName = inp.value;
+			var href = null;
+			
+			var visible = 'off';
+			var media = 'off';
+			
+			for(var j=0; j<inputs.length; ++j){
+				if(inputs[j].name == 'fieldValue' + itemID){
+					fieldValue = escapeForXML(inputs[j].value);
 				}
-				for(var j=0; j<selects.length; ++j){
-					if(selects[j].name == 'visible' + itemID){
-						visible = escapeForXML(selects[j].value);
-					}
-					if(selects[j].name == 'media' + itemID){
-						media = escapeForXML(selects[j].value);
-					}
+				if(inputs[j].name == 'href' + itemID){
+					href = escapeForXML(inputs[j].value);
 				}
-				
-				information += "<field name=\"" + fieldName + "\"";
-				
-				information += " visible=\""+visible+"\"";
-				if(href!=null){
-					information += " href=\""+href+"\"";
+			}
+			for(var j=0; j<selects.length; ++j){
+				if(selects[j].name == 'visible' + itemID){
+					visible = escapeForXML(selects[j].value);
 				}
-				information += " media=\""+media+"\"";
-				
-				information += ">";
-				information += (fieldValue==null?"":fieldValue);
-				information += "</field>";
-				
-            }
+				if(selects[j].name == 'media' + itemID){
+					media = escapeForXML(selects[j].value);
+				}
+			}
+			
+			information += "<field name=\"" + fieldName + "\"";
+			
+			information += " visible=\""+visible+"\"";
+			if(href!=null){
+				information += " href=\""+href+"\"";
+			}
+			information += " media=\""+media+"\"";
+			
+			information += ">";
+			information += (fieldValue==null?"":fieldValue);
+			information += "</field>";
+			
         }
     }
 	information += "</information>";
-
-	
 	return information;
 }
 
@@ -2596,7 +2637,7 @@ gbEditFormPlot.prototype.close = function(btn){
     
 	if(btn == 'ok'){
 	    var information = this.getInfoXML();
-	    
+	    trace("gbEditFormPlot information="+information);
 	    var app = this.getApp();
     	
     	var mark = app.activeVct.getCurrentMark();
@@ -2640,7 +2681,7 @@ gbEditFormPlot.prototype.clearFields = function()
 {
 	var tbody = getObjectById("editFormTbody");
 	for(var i=tbody.rows.length-1; i>=0; --i){
-		var inputs = tbody.rows[i].getElementsByTagName('input');
+		var inputs = getElementsByTagName_alt(tbody.rows[i], null, 'input');
 		for(var j=0; j<inputs.length; ++j){
 			if(inputs[j].name.indexOf('fieldName') == 0){
 				tbody.deleteRow(i);
@@ -2662,7 +2703,7 @@ gbEditFormPlot.prototype.deleteItem = function(caption){
 
 gbEditFormPlot.prototype.isFieldExists = function(name){
     var tbody = getObjectById('editFormTbody');
-    var inputs = tbody.getElementsByTagName('input');
+    var inputs = getElementsByTagName_alt(tbody, null, 'input');
     for(var i=0; i<inputs.length; ++i){
         if(inputs[i].value == name){
             if(inputs[i].name.indexOf('field')==0 && inputs[i].name.indexOf('Caption')!=-1){
@@ -2674,6 +2715,7 @@ gbEditFormPlot.prototype.isFieldExists = function(name){
 }
 
 gbEditFormPlot.prototype.addItem = function(hasAttributes, name, value, visible, href, media){
+//	alert("addItem hasAttributes"=hasAttributes+" name="+name+" value="+value+" visible="+visible+" href="+href+" media="+media);
     if(!name){
 	    name = prompt("項目名を入力して下さい。", "");
 	    if(name == null || name == ''){
@@ -2713,7 +2755,7 @@ gbEditFormPlot.prototype.addItem = function(hasAttributes, name, value, visible,
 	   
 	var tbody = getObjectById("editFormTbody");
 	if(tbody == null){
-		alert("editFormTbodyが見つかりません。");
+		alert("editFormTbody was not found. main.html needs this");
 		return;
 	}
 	var itemCount = tbody.rows.length-2;
@@ -2756,26 +2798,6 @@ gbEditFormPlot.prototype.addItem = function(hasAttributes, name, value, visible,
 		
 		td.innerHTML = hrefHtml;
 	}
-	/*
-	td = tr.insertCell(colIndex++);
-	if(hasAttributes){
-		td.innerHTML = "<select name=\"media"+itemCount+"\">"+
-			"<option "+(media=='off'?"selected=\"1\"":"")+" value=\"off\">off</option>"+
-			"<option "+(media=='image'?"selected=\"1\"":"")+" value=\"image\">画像</option></select>";
-	}
-	
-	td = tr.insertCell(colIndex++);
-	if(this.isRequiredField(name)){
-	    td.innerHTML = "";
-	}
-	else{
-        td.innerHTML = "<input type=button value=\"項目削除\" onclick=\"theApp.editForm_deleteItem('"+caption+"')\">";
-	}
-	*/
-}
-
-gbEditFormPlot.prototype.isRequiredField = function(name){
-    return (name == "name");
 }
 
 
@@ -2793,7 +2815,7 @@ function gbSetPostedFileName(index, name, isImage){
 	var postFileForm = getObjectById('postFileForm');
 	postFileForm.style.visibility = 'hidden';
 	var tbody = getObjectById("editFormTbody");
-	var inputs = tbody.getElementsByTagName("input");
+	var inputs = getElementsByTagName_alt(tbody, null, 'input');
 	var hrefField = "href"+index;
 	
 	for(var i=0; i<inputs.length; ++i){
@@ -2804,7 +2826,7 @@ function gbSetPostedFileName(index, name, isImage){
 	}
 	
 	if(isImage){
-		var selects = tbody.getElementsByTagName("select");
+		var selects = getElementsByTagName_alt(tbody, null, 'select');
 		for(var i=0; i<selects.length; ++i){
 			if(selects[i].name == ("media"+index)){
 				selects[i].value = 'image';
@@ -2814,6 +2836,131 @@ function gbSetPostedFileName(index, name, isImage){
 	}
 }
 
+function gbGetOS()
+{
+	var agent  = navigator.userAgent.toUpperCase();
+    if (agent.indexOf("MAC") >= 0)
+    	return "MAC";
+    if (agent.indexOf("WIN") >= 0)
+    	return "WINDOWS";
+    if (agent.indexOf("X11") >= 0)
+    	return "UNIX";
+	return "";
+}
+
+
+function gbSetupDownloadDiv(app, targetDivId){
+	try{
+		gbDownloadDiv(app.getCgiPath()+"?md=getReleaseRSS", targetDivId);
+	}
+	catch(e){
+		trace(e);
+		alert(e);
+	}
+}
+
+function gbDownloadDiv(url, targetDivId){
+	gbDownloadDiv.htmlId = targetDivId;
+	
+	var req = doRequest(url, false);
+	
+	if(isResponseOK(req)){
+		var doc = req.responseXML;
+		var channel = getElementsByTagName_alt(doc, null, 'channel');
+		gbCheckHttpResponse(req);
+		
+		gbDownloadDiv.topURL = getChildrenText(getElementsByTagName_alt(channel[0], null, 'link')[0]);
+		
+		var itemNodes = getElementsByTagName_alt(doc, null, 'item');
+		var items = [];
+		for(var i=0; i<itemNodes.length; ++i){
+			var item = {};
+			for(var node = itemNodes[i].firstChild; node != null; node = node.nextSibling){
+				if(node.nodeName == "title"){
+					item.title = getChildrenText(node);
+				}
+				else if(node.nodeName == "link"){
+					item.link = getChildrenText(node);
+				}
+				else if(node.nodeName == "description"){
+					item.description = getChildrenText(node);
+				}
+				else if(node.nodeName == "dc:date"||node.nodeName == "date"){
+					item.date = getChildrenText(node);
+				}
+			}
+			items.push(item);
+		}
+		gbDownloadDiv.items = items;
+		
+		gbDownloadDiv.setupHtml();
+		gbDownloadDiv.getSelectBox().onchange = gbDownloadDiv.updateDescription;
+	}
+}
+
+gbDownloadDiv.getDescriptionDiv = function(){
+	return getObjectById(gbDownloadDiv.htmlId+"_description");
+}
+
+gbDownloadDiv.getDateDiv = function(){
+	return getObjectById(gbDownloadDiv.htmlId+"_date");
+}
+
+gbDownloadDiv.getSelectBox = function(){
+	return getObjectById(gbDownloadDiv.htmlId+"_select");
+}
+
+gbDownloadDiv.getSelectedItem = function(){
+	return gbDownloadDiv.items[gbDownloadDiv.getSelectBox().value];
+}
+
+gbDownloadDiv.updateDescription = function(){
+	var item = gbDownloadDiv.getSelectedItem();
+	if(item){
+		var d = gbDownloadDiv.getDescriptionDiv();
+		if(d){
+			d.innerHTML = item.description;
+		}
+		d = gbDownloadDiv.getDateDiv();
+		if(d){
+			d.innerHTML = item.date;
+		}
+	}
+}
+
+gbDownloadDiv.setupHtml = function(){
+	
+	var os = gbGetOS();
+	var items = gbDownloadDiv.items;
+	var selectedItem=null;
+	var selBox = gbDownloadDiv.getSelectBox();
+	
+	
+	for(var i=0; i<items.length; ++i){
+		var title = items[i].title.toUpperCase();
+		
+		var selected = false;
+		if(title.indexOf("WINDOWS") >=0 && os == "WINDOWS"){
+			selected = true;
+		}
+		else if(title.indexOf("MAC") >=0 && os == "MAC"){
+			selected = true;
+		}
+		if(selected){
+			selectedItem = items[i];
+		}
+		selBox.options[i] = new Option(items[i].title, i, selected, selected);
+	}
+	
+	if(selectedItem){
+		gbDownloadDiv.updateDescription();
+	}
+}
+
+gbDownloadDiv.doDownload = function(){
+	document.location = gbDownloadDiv.getSelectedItem().link;
+}
+
 
 function gbCreateApp(confFile, accessParam, cgiPath, imagesPath)
 {
